# Changelog

All notable changes to this project will be documented in this file.

## [1.0.0] - 2025-02-04

### Added
- Initial release of Seekify.
- Unified text search API supporting Google, Bing, DuckDuckGo, Brave, Yahoo, Yandex, Mojeek, Grokipedia.
- Multimedia search support (Images, Videos) via DuckDuckGo.
- News search support via Bing, DuckDuckGo, Yahoo.
- Book search support via Anna's Archive.
- Robust CLI tool with export capabilities (CSV, JSON).
- Full proxy support (HTTP/SOCKS5).
- Comprehensive test suite.
